@@ -1,105 +1,126 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.0" language="hr_HR">
+<TS version="2.1" language="hr">
 <context>
     <name>AdvancedSettings</name>
     <message>
-        <source>Menu Configuration</source>
-        <translation type="unfinished">Konfiguracija izbornika</translation>
-    </message>
-    <message>
-        <source>Notification Duration</source>
-        <translation type="unfinished">Trajanje obavijesti</translation>
-    </message>
-    <message>
-        <source>For some the notification&apos;s expiration time is dependent on the notification server&apos;s settings.</source>
-        <translation type="unfinished">Za neke obavijesti&apos;s vrijeme istjecanja ovisi o postavkama poslužitelja&apos;s obavijesti</translation>
-    </message>
-    <message>
-        <source>&quot;Server Decides&quot; Time:</source>
+        <location filename="../advancedsettings.ui" line="25"/>
+        <source>Width:</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../advancedsettings.ui" line="49"/>
+        <source>Spacing:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="68"/>
+        <source>Duration</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="80"/>
+        <source>Some notifications set their own on-screen duration.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="92"/>
+        <source>Default duration:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source> sec</source>
         <translation type="unfinished">sek</translation>
     </message>
     <message>
+        <location filename="../advancedsettings.ui" line="127"/>
+        <source>Unattended Notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="135"/>
+        <source>How many to save:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="159"/>
+        <source>Application name is on the top of notification.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="152"/>
+        <source>Ignore these applications:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="162"/>
+        <source>app1,app2,app3</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="17"/>
         <source>Sizes</source>
         <translation type="unfinished">Veličine</translation>
     </message>
     <message>
-        <source>Notification Spacing:</source>
-        <translation type="unfinished">Razmak obavijesti</translation>
-    </message>
-    <message>
+        <location filename="../advancedsettings.ui" line="32"/>
+        <location filename="../advancedsettings.ui" line="56"/>
         <source> px</source>
         <translation type="unfinished"> px</translation>
     </message>
-    <message>
-        <source>Notification Width:</source>
-        <translation type="unfinished">Širina obavijesti</translation>
-    </message>
 </context>
 <context>
     <name>BasicSettings</name>
     <message>
+        <location filename="../basicsettings.ui" line="23"/>
         <source>Basic Settings</source>
         <translation type="unfinished">Osnovne postavke</translation>
     </message>
     <message>
-        <source>Display Notifications</source>
-        <translation type="unfinished">Prikaži obavijesti</translation>
-    </message>
-    <message>
-        <source>Top/Left</source>
-        <translation type="unfinished">Gore/lijevo</translation>
-    </message>
-    <message>
-        <source>Top/Right</source>
-        <translation type="unfinished">Gore/desno</translation>
-    </message>
-    <message>
-        <source>Bottom/Left</source>
-        <translation type="unfinished">Dolje/lijevo</translation>
-    </message>
-    <message>
-        <source>Bottom/Right</source>
-        <translation type="unfinished">Dolje/desno</translation>
-    </message>
-    <message>
-        <source>Test Notification</source>
-        <translation type="unfinished">Isprobaj obavijesti</translation>
+        <location filename="../basicsettings.ui" line="30"/>
+        <source>Position on screen</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../basicsettings.cpp" line="56"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
+        <location filename="../basicsettings.cpp" line="59"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
-These settings won&apos;t have an effect on it!</source>
+These settings won&apos;t have any effect on it!</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Notification Summary</source>
-        <translation type="unfinished">Sažetak obavijesti</translation>
+        <location filename="../basicsettings.cpp" line="112"/>
+        <source>Notification demo </source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Notification Body</source>
+        <location filename="../basicsettings.cpp" line="113"/>
+        <source>This is a test notification.
+ All notifications will now appear here on LXQt.</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../mainwindow.cpp" line="41"/>
         <source>Desktop Notifications</source>
         <translation type="unfinished">Obavijesti radne površine</translation>
     </message>
     <message>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Basic Settings</source>
         <translation type="unfinished">Osnovne postavke</translation>
     </message>
     <message>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Advanced Settings</source>
         <translation type="unfinished">Napredne postavke</translation>
     </message>
