@@ -1,6 +1,6 @@
 <?xml version="1.0" encoding="utf-8"?>
 <!DOCTYPE TS>
-<TS version="2.1" language="hu_HU">
+<TS version="2.1" language="hu">
 <context>
     <name>AdvancedSettings</name>
     <message>
@@ -30,20 +30,46 @@
         <translation>Tartam</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="74"/>
+        <location filename="../advancedsettings.ui" line="80"/>
         <source>Some notifications set their own on-screen duration.</source>
-        <translation>Egyes értesítések megjelenési ideje</translation>
+        <translation>Egyes értesítések megjelenési ideje.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="86"/>
+        <location filename="../advancedsettings.ui" line="92"/>
         <source>Default duration:</source>
         <translation>Alapértelmezett tartam:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="93"/>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source> sec</source>
         <translation> mp</translation>
     </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="127"/>
+        <source>Unattended Notifications</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="135"/>
+        <source>How many to save:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="159"/>
+        <source>Application name is on the top of notification.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="152"/>
+        <source>Ignore these applications:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="162"/>
+        <source>app1,app2,app3</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>BasicSettings</name>
@@ -58,27 +84,7 @@
         <translation>Hely</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="36"/>
-        <source>Top/Left</source>
-        <translation>Balra fenn</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="43"/>
-        <source>Top/Right</source>
-        <translation>Jobbra fenn</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="50"/>
-        <source>Bottom/Left</source>
-        <translation>Balra lenn</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="57"/>
-        <source>Bottom/Right</source>
-        <translation>Jobbra lenn</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.cpp" line="53"/>
+        <location filename="../basicsettings.cpp" line="56"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Értesítő démon nem fut.
@@ -88,36 +94,36 @@ A vésztartalék használatos.</translation>
         <location filename="../basicsettings.cpp" line="59"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
-        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; A (%1) démont már valaki futtatja.
+        <translation>&lt;b&gt;Figyelem:&lt;/b&gt; Egy másik, a (%1) értesítésfigyelő már fut.
 Ezek a beállítások arra már hatástalanok!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="98"/>
-        <source>Notification demo</source>
-        <translation>Értesítési bemutató</translation>
+        <location filename="../basicsettings.cpp" line="112"/>
+        <source>Notification demo </source>
+        <translation>Értesítés bemutató </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="99"/>
+        <location filename="../basicsettings.cpp" line="113"/>
         <source>This is a test notification.
-All notifications will now appear here on LXQt.</source>
-        <translation>Az értesítés tesztje
-Minden értesítést megjelenít az LXQt.</translation>
+ All notifications will now appear here on LXQt.</source>
+        <translation>Értesítési teszt.
+ Az értesítéseket az LXQt így fogja megjeleníteni.</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="40"/>
+        <location filename="../mainwindow.cpp" line="41"/>
         <source>Desktop Notifications</source>
         <translation>Asztali értesítések</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="43"/>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Basic Settings</source>
         <translation>Alapbeállítások</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Advanced Settings</source>
         <translation>Haladó beállítások</translation>
     </message>
