@@ -30,20 +30,46 @@
         <translation>Длительность</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="74"/>
+        <location filename="../advancedsettings.ui" line="80"/>
         <source>Some notifications set their own on-screen duration.</source>
         <translation>Некоторые уведомления сами устанавливают свою длительность на экране.</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="86"/>
+        <location filename="../advancedsettings.ui" line="92"/>
         <source>Default duration:</source>
         <translation>Длительность по умолчанию:</translation>
     </message>
     <message>
-        <location filename="../advancedsettings.ui" line="93"/>
+        <location filename="../advancedsettings.ui" line="99"/>
         <source> sec</source>
         <translation> сек</translation>
     </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="127"/>
+        <source>Unattended Notifications</source>
+        <translation>Непрочитанные уведомления</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="135"/>
+        <source>How many to save:</source>
+        <translation>Сколько сохранять:</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="149"/>
+        <location filename="../advancedsettings.ui" line="159"/>
+        <source>Application name is on the top of notification.</source>
+        <translation>Имя приложения находится вверху уведомления.</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="152"/>
+        <source>Ignore these applications:</source>
+        <translation>Игнорировать приложения:</translation>
+    </message>
+    <message>
+        <location filename="../advancedsettings.ui" line="162"/>
+        <source>app1,app2,app3</source>
+        <translation>app1,app2,app3</translation>
+    </message>
 </context>
 <context>
     <name>BasicSettings</name>
@@ -58,27 +84,7 @@
         <translation>Расположение на экране</translation>
     </message>
     <message>
-        <location filename="../basicsettings.ui" line="36"/>
-        <source>Top/Left</source>
-        <translation>Вверху слева</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="43"/>
-        <source>Top/Right</source>
-        <translation>Вверху справа</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="50"/>
-        <source>Bottom/Left</source>
-        <translation>Внизу слева</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.ui" line="57"/>
-        <source>Bottom/Right</source>
-        <translation>Внизу справа</translation>
-    </message>
-    <message>
-        <location filename="../basicsettings.cpp" line="53"/>
+        <location filename="../basicsettings.cpp" line="56"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; No notifications daemon is running.
 A fallback will be used.</source>
         <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений не запущен.
@@ -88,36 +94,36 @@ A fallback will be used.</source>
         <location filename="../basicsettings.cpp" line="59"/>
         <source>&lt;b&gt;Warning:&lt;/b&gt; A third-party notifications daemon (%1) is running.
 These settings won&apos;t have any effect on it!</source>
-        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Демон уведомлений третьей сторон (%1) запущен.
+        <translation>&lt;b&gt;Внимание:&lt;/b&gt; Запущен сторонний демон уведомлений (%1).
 Эти настройки не будут иметь никакого эффекта для него!</translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="98"/>
-        <source>Notification demo</source>
-        <translation>Демонстрация уведомления</translation>
+        <location filename="../basicsettings.cpp" line="112"/>
+        <source>Notification demo </source>
+        <translation>Тестовое уведомление </translation>
     </message>
     <message>
-        <location filename="../basicsettings.cpp" line="99"/>
+        <location filename="../basicsettings.cpp" line="113"/>
         <source>This is a test notification.
-All notifications will now appear here on LXQt.</source>
+ All notifications will now appear here on LXQt.</source>
         <translation>Это тестовое уведомление.
-Все уведомления на LXQt будут появляться здесь.</translation>
+ Теперь все уведомления LQXt будут появляться здесь.</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../mainwindow.cpp" line="40"/>
+        <location filename="../mainwindow.cpp" line="41"/>
         <source>Desktop Notifications</source>
         <translation>Системные уведомления</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="43"/>
+        <location filename="../mainwindow.cpp" line="44"/>
         <source>Basic Settings</source>
         <translation>Основные настройки</translation>
     </message>
     <message>
-        <location filename="../mainwindow.cpp" line="47"/>
+        <location filename="../mainwindow.cpp" line="48"/>
         <source>Advanced Settings</source>
         <translation>Расширенные настройки</translation>
     </message>
